pub struct StructuredName {
pub given: MultilingualString,
pub family: MultilingualString,
pub suffix: Option<String>,
pub dropping_particle: Option<String>,
pub non_dropping_particle: Option<String>,
}Expand description
A structured name is a name broken down into its constituent parts.
Fields
given: MultilingualStringfamily: MultilingualStringsuffix: Option<String>dropping_particle: Option<String>non_dropping_particle: Option<String>Trait Implementations
Sourceimpl Clone for StructuredName
impl Clone for StructuredName
Sourcefn clone(&self) -> StructuredName
fn clone(&self) -> StructuredName
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StructuredName
impl Debug for StructuredName
Sourceimpl Default for StructuredName
impl Default for StructuredName
Sourcefn default() -> StructuredName
fn default() -> StructuredName
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for StructuredName
impl<'de> Deserialize<'de> for StructuredName
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for StructuredName
impl PartialEq for StructuredName
Sourcefn eq(&self, other: &StructuredName) -> bool
fn eq(&self, other: &StructuredName) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for StructuredName
impl Serialize for StructuredName
impl StructuralPartialEq for StructuredName