pub enum IntegralNameState {
First,
Subsequent,
}Expand description
Explicit integral citation name-memory state for one citation item.
Variants
First
Render this item as the first integral mention in scope.
Subsequent
Render this item as a subsequent integral mention in scope.